@@ -8,9 +8,28 @@ from front.util import deep_merge
 
 
 class ElementTreeMaker:
+    """Takes care of generating the composite tree of elements based on the "rendering"
+    specification previously compiled from the configuration. This composite tree will
+    then be used to build the application by rendering each element recursively from
+    the root of the tree (the App container).
+    """
+
     def mk_tree(
         self, front_objs: Iterable[Any], rendering_spec: dict
     ) -> FrontContainerBase:
+        """Entrypoint of the ElementTreeMaker class. Builds the composite tree
+        
+        :param front_objs: The objects to render after transformation (see AppMaker).
+        :param rendering_spec: The rendering spec of the application, compiled from
+            the given configuration.
+            This nested object contains information on how an object should be rendered
+            based on its type (general spec that can be reused for several objects) or
+            its name (specific spec for a single object). Both specs can be used for a
+            single objects. In that case, the spec that will be used for this object
+            will be a combination between those two specs (any value in the specific
+            spec overwrites the value in the general spec for any key that they could
+            have in common).
+        """
         self.front_objs = front_objs
         self.rendering_spec = dict(rendering_spec)
         root_factory = self._get_root_factory()
